@@ -1,4 +1,5 @@
-mod generators;
+pub mod generators;
+mod model_struct;
 
 use expansion::helpers::{DeriveInputHelper};
 
@@ -20,5 +21,5 @@ pub fn create_arel(args: TokenStream, input: TokenStream) -> TokenStream {
 }
 
 fn do_expand(derive_input_helper: &DeriveInputHelper, args: &AttributeArgs) -> syn::Result<proc_macro2::TokenStream> {
-    generators::generate_struct(derive_input_helper, args)
+    model_struct::generate(derive_input_helper, args)
 }
\ No newline at end of file
